==> codebuild-1.195.0-sources.jar: software/amazon/awscdk/services/codebuild/CfnSourceCredentialProps.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * Properties for defining a `CfnSourceCredential`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.codebuild.*;
 * CfnSourceCredentialProps cfnSourceCredentialProps = CfnSourceCredentialProps.builder()
 *         .authType("authType")
 *         .serverType("serverType")
 *         .token("token")
 *         // the properties below are optional
 *         .username("username")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.74.0 (build 6d08790)", date = "2023-03-02T14:17:21.981Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.CfnSourceCredentialProps")
@software.amazon.jsii.Jsii.Proxy(CfnSourceCredentialProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSourceCredentialProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The type of authentication used by the credentials.
     * <p>
     * Valid options are OAUTH, BASIC_AUTH, or PERSONAL_ACCESS_TOKEN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAuthType();

    /**
     * The type of source provider.
     * <p>
     * The valid options are GITHUB, GITHUB_ENTERPRISE, or BITBUCKET.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getServerType();

    /**
     * For GitHub or GitHub Enterprise, this is the personal access token.
     * <p>
     * For Bitbucket, this is the app password.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getToken();

    /**
     * The Bitbucket username when the `authType` is BASIC_AUTH.
     * <p>
     * This parameter is not valid for other types of source providers or connections.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getUsername() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnSourceCredentialProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSourceCredentialProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSourceCredentialProps> {
        java.lang.String authType;
        java.lang.String serverType;
        java.lang.String token;
        java.lang.String username;

        /**
         * Sets the value of {@link CfnSourceCredentialProps#getAuthType}
         * @param authType The type of authentication used by the credentials. This parameter is required.
         *                 Valid options are OAUTH, BASIC_AUTH, or PERSONAL_ACCESS_TOKEN.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder authType(java.lang.String authType) {
            this.authType = authType;
            return this;
        }

        /**
         * Sets the value of {@link CfnSourceCredentialProps#getServerType}
         * @param serverType The type of source provider. This parameter is required.
         *                   The valid options are GITHUB, GITHUB_ENTERPRISE, or BITBUCKET.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder serverType(java.lang.String serverType) {
            this.serverType = serverType;
            return this;
        }

        /**
         * Sets the value of {@link CfnSourceCredentialProps#getToken}
         * @param token For GitHub or GitHub Enterprise, this is the personal access token. This parameter is required.
         *              For Bitbucket, this is the app password.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder token(java.lang.String token) {
            this.token = token;
            return this;
        }

        /**
         * Sets the value of {@link CfnSourceCredentialProps#getUsername}
         * @param username The Bitbucket username when the `authType` is BASIC_AUTH.
         *                 This parameter is not valid for other types of source providers or connections.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder username(java.lang.String username) {
            this.username = username;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSourceCredentialProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSourceCredentialProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnSourceCredentialProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSourceCredentialProps {
        private final java.lang.String authType;
        private final java.lang.String serverType;
        private final java.lang.String token;
        private final java.lang.String username;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.authType = software.amazon.jsii.Kernel.get(this, "authType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.serverType = software.amazon.jsii.Kernel.get(this, "serverType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.token = software.amazon.jsii.Kernel.get(this, "token", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.username = software.amazon.jsii.Kernel.get(this, "username", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.authType = java.util.Objects.requireNonNull(builder.authType, "authType is required");
            this.serverType = java.util.Objects.requireNonNull(builder.serverType, "serverType is required");
            this.token = java.util.Objects.requireNonNull(builder.token, "token is required");
            this.username = builder.username;
        }

        @Override
        public final java.lang.String getAuthType() {
            return this.authType;
        }

        @Override
        public final java.lang.String getServerType() {
            return this.serverType;
        }

        @Override
        public final java.lang.String getToken() {
            return this.token;
        }

        @Override
        public final java.lang.String getUsername() {
            return this.username;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("authType", om.valueToTree(this.getAuthType()));
            data.set("serverType", om.valueToTree(this.getServerType()));
            data.set("token", om.valueToTree(this.getToken()));
            if (this.getUsername() != null) {
                data.set("username", om.valueToTree(this.getUsername()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codebuild.CfnSourceCredentialProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSourceCredentialProps.Jsii$Proxy that = (CfnSourceCredentialProps.Jsii$Proxy) o;

            if (!authType.equals(that.authType)) return false;
            if (!serverType.equals(that.serverType)) return false;
            if (!token.equals(that.token)) return false;
            return this.username != null ? this.username.equals(that.username) : that.username == null;
        }

        @Override
        public final int hashCode() {
            int result = this.authType.hashCode();
            result = 31 * result + (this.serverType.hashCode());
            result = 31 * result + (this.token.hashCode());
            result = 31 * result + (this.username != null ? this.username.hashCode() : 0);
            return result;
        }
    }
}

==> codebuild-1.204.0-sources.jar: software/amazon/awscdk/services/codebuild/CfnSourceCredentialProps.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * Properties for defining a <code>CfnSourceCredential</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.codebuild.*;
 * CfnSourceCredentialProps cfnSourceCredentialProps = CfnSourceCredentialProps.builder()
 *         .authType("authType")
 *         .serverType("serverType")
 *         .token("token")
 *         // the properties below are optional
 *         .username("username")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:30:41.766Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.CfnSourceCredentialProps")
@software.amazon.jsii.Jsii.Proxy(CfnSourceCredentialProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSourceCredentialProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The type of authentication used by the credentials.
     * <p>
     * Valid options are OAUTH, BASIC_AUTH, or PERSONAL_ACCESS_TOKEN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAuthType();

    /**
     * The type of source provider.
     * <p>
     * The valid options are GITHUB, GITHUB_ENTERPRISE, or BITBUCKET.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getServerType();

    /**
     * For GitHub or GitHub Enterprise, this is the personal access token.
     * <p>
     * For Bitbucket, this is the app password.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getToken();

    /**
     * The Bitbucket username when the <code>authType</code> is BASIC_AUTH.
     * <p>
     * This parameter is not valid for other types of source providers or connections.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getUsername() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnSourceCredentialProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSourceCredentialProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSourceCredentialProps> {
        java.lang.String authType;
        java.lang.String serverType;
        java.lang.String token;
        java.lang.String username;

        /**
         * Sets the value of {@link CfnSourceCredentialProps#getAuthType}
         * @param authType The type of authentication used by the credentials. This parameter is required.
         *                 Valid options are OAUTH, BASIC_AUTH, or PERSONAL_ACCESS_TOKEN.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder authType(java.lang.String authType) {
            this.authType = authType;
            return this;
        }

        /**
         * Sets the value of {@link CfnSourceCredentialProps#getServerType}
         * @param serverType The type of source provider. This parameter is required.
         *                   The valid options are GITHUB, GITHUB_ENTERPRISE, or BITBUCKET.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder serverType(java.lang.String serverType) {
            this.serverType = serverType;
            return this;
        }

        /**
         * Sets the value of {@link CfnSourceCredentialProps#getToken}
         * @param token For GitHub or GitHub Enterprise, this is the personal access token. This parameter is required.
         *              For Bitbucket, this is the app password.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder token(java.lang.String token) {
            this.token = token;
            return this;
        }

        /**
         * Sets the value of {@link CfnSourceCredentialProps#getUsername}
         * @param username The Bitbucket username when the <code>authType</code> is BASIC_AUTH.
         *                 This parameter is not valid for other types of source providers or connections.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder username(java.lang.String username) {
            this.username = username;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSourceCredentialProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSourceCredentialProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnSourceCredentialProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSourceCredentialProps {
        private final java.lang.String authType;
        private final java.lang.String serverType;
        private final java.lang.String token;
        private final java.lang.String username;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.authType = software.amazon.jsii.Kernel.get(this, "authType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.serverType = software.amazon.jsii.Kernel.get(this, "serverType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.token = software.amazon.jsii.Kernel.get(this, "token", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.username = software.amazon.jsii.Kernel.get(this, "username", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.authType = java.util.Objects.requireNonNull(builder.authType, "authType is required");
            this.serverType = java.util.Objects.requireNonNull(builder.serverType, "serverType is required");
            this.token = java.util.Objects.requireNonNull(builder.token, "token is required");
            this.username = builder.username;
        }

        @Override
        public final java.lang.String getAuthType() {
            return this.authType;
        }

        @Override
        public final java.lang.String getServerType() {
            return this.serverType;
        }

        @Override
        public final java.lang.String getToken() {
            return this.token;
        }

        @Override
        public final java.lang.String getUsername() {
            return this.username;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("authType", om.valueToTree(this.getAuthType()));
            data.set("serverType", om.valueToTree(this.getServerType()));
            data.set("token", om.valueToTree(this.getToken()));
            if (this.getUsername() != null) {
                data.set("username", om.valueToTree(this.getUsername()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codebuild.CfnSourceCredentialProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSourceCredentialProps.Jsii$Proxy that = (CfnSourceCredentialProps.Jsii$Proxy) o;

            if (!authType.equals(that.authType)) return false;
            if (!serverType.equals(that.serverType)) return false;
            if (!token.equals(that.token)) return false;
            return this.username != null ? this.username.equals(that.username) : that.username == null;
        }

        @Override
        public final int hashCode() {
            int result = this.authType.hashCode();
            result = 31 * result + (this.serverType.hashCode());
            result = 31 * result + (this.token.hashCode());
            result = 31 * result + (this.username != null ? this.username.hashCode() : 0);
            return result;
        }
    }
}
